pub struct SparseIndexEntry {
pub key: Vec<u8>,
pub offset: u64,
pub version: u64,
}Expand description
Entry in the sparse index that aids in binary search during lookups
Fields
key: Vec<u8>Key for this index entry
offset: u64Byte offset where this entry starts in the segment
version: u64Version number of the command