EntryGuard

Struct EntryGuard 

pub struct EntryGuard<'a> { /* private fields */ }
Guard for a locked shard entry that allows atomic operations

Implementations

Source

impl<'a> EntryGuard<'a>

pub fn evaluate(&self, command: &Command) -> ApplyOutcome

Evaluates what would happen if the command were applied without mutating state

pub fn apply(&mut self, command: &Command) -> ApplyOutcome

Applies a command to the locked entry and returns the outcome