pub struct EntryGuard<'a> { /* private fields */ }Expand description
Guard for a locked shard entry that allows atomic operations
Implementations
Sourceimpl<'a> EntryGuard<'a>
impl<'a> EntryGuard<'a>
Sourcepub fn evaluate(&self, command: &Command) -> ApplyOutcome
pub fn evaluate(&self, command: &Command) -> ApplyOutcome
Evaluates what would happen if the command were applied without mutating state
Sourcepub fn apply(&mut self, command: &Command) -> ApplyOutcome
pub fn apply(&mut self, command: &Command) -> ApplyOutcome
Applies a command to the locked entry and returns the outcome